==> flutter_kakaolink-0.0.3.tar.gz: android/src/main/java/com/dh/flutterkakaolink/FlutterKakaolinkPlugin.java <==
package com.dh.flutterkakaolink;

import android.content.Context;

import com.kakao.kakaolink.v2.KakaoLinkResponse;
import com.kakao.kakaolink.v2.KakaoLinkService;
import com.kakao.message.template.LinkObject;
import com.kakao.message.template.TextTemplate;
import com.kakao.network.ErrorResult;
import com.kakao.network.callback.ResponseCallback;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** FlutterKakaolinkPlugin */
public class FlutterKakaolinkPlugin implements MethodCallHandler {
    Context mcontext;

  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final FlutterKakaolinkPlugin plugin = new FlutterKakaolinkPlugin(registrar);
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_kakaolink");
    channel.setMethodCallHandler(plugin);
  }

    private FlutterKakaolinkPlugin(Registrar registrar) {
        mcontext = registrar.context();
    }

    TextTemplate params = TextTemplate.newBuilder("Text", LinkObject.newBuilder().
            setWebUrl("https://developers.kakao.com").
            setMobileWebUrl("https://developers.kakao.com").
            build()).setButtonTitle("This is button").build();



  @Override
  public void onMethodCall(MethodCall call, final Result result) {
    if (call.method.equals("reqkakalink")) {
        Map<String, String> serverCallbackArgs = new HashMap<String, String>();
        serverCallbackArgs.put("user_id", "${current_user_id}");
        serverCallbackArgs.put("product_id", "${shared_product_id}");

        KakaoLinkService.getInstance().sendDefault(mcontext, params, serverCallbackArgs, new ResponseCallback<KakaoLinkResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                result.success(null);
            }

            @Override
            public void onSuccess(KakaoLinkResponse successResult) {
                result.success(null);
            }
        });
    } else {
      result.notImplemented();
    }
  }
}

==> flutter_kakaolink-0.0.14.tar.gz: android/src/main/java/com/dh/flutterkakaolink/FlutterKakaolinkPlugin.java <==
package com.dh.flutterkakaolink;

import android.content.Context;

import com.kakao.kakaolink.v2.KakaoLinkResponse;
import com.kakao.kakaolink.v2.KakaoLinkService;
import com.kakao.message.template.LinkObject;
import com.kakao.message.template.TextTemplate;
import com.kakao.network.ErrorResult;
import com.kakao.network.callback.ResponseCallback;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** FlutterKakaolinkPlugin */
public class FlutterKakaolinkPlugin implements MethodCallHandler {
    Context mcontext;

  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final FlutterKakaolinkPlugin plugin = new FlutterKakaolinkPlugin(registrar);
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_kakaolink");
    channel.setMethodCallHandler(plugin);
  }

    private FlutterKakaolinkPlugin(Registrar registrar) {
        mcontext = registrar.context();
    }

    



  @Override
  public void onMethodCall(MethodCall call, final Result result) {
    if (call.method.equals("reqkakalink")) {
        Map<String, String> serverCallbackArgs = new HashMap<String, String>();
        serverCallbackArgs.put("user_id", "${current_user_id}");
        serverCallbackArgs.put("product_id", "${shared_product_id}");

        TextTemplate params = TextTemplate.newBuilder("", LinkObject.newBuilder().
            setWebUrl((String)call.arguments).
            setMobileWebUrl((String)call.arguments).
            build()).setButtonTitle("Download").build();

        KakaoLinkService.getInstance().sendDefault(mcontext, params, serverCallbackArgs, new ResponseCallback<KakaoLinkResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                result.success(null);
            }

            @Override
            public void onSuccess(KakaoLinkResponse successResult) {
                result.success(null);
            }
        });

        // 기본적인 스크랩 템플릿을 사용하여 보내는 코드
        //Map<String, String> serverCallbackArgs = new HashMap<String, String>();
        //serverCallbackArgs.put("user_id", "${current_user_id}");
        //serverCallbackArgs.put("product_id", "${shared_product_id}");

        //KakaoLinkService.getInstance().sendScrap(mcontext, (String)call.arguments, serverCallbackArgs, new ResponseCallback<KakaoLinkResponse>() {
        //    @Override
        //    public void onFailure(ErrorResult errorResult) {
        //        result.success(null);
        //    }

        //    @Override
        //    public void onSuccess(KakaoLinkResponse resultkakao) {
        //        // 템플릿 밸리데이션과 쿼터 체크가 성공적으로 끝남. 톡에서 정상적으로 보내졌는지 보장은 할 수 없다. 전송 성공 유무는 서버콜백 기능을 이용하여야 한다.
        //        result.success(null);
        //    }
        //});
    } else {
      result.notImplemented();
    }
  }
}
